@@ -1,12 +1,11 @@
 objref = function (obj)
-{	f = function () .objref.image ()
+{	f = function () .$obj
 	extend (FUNCTION (f, obj), "objref")
 }
 
 print.objref = function (ref, ...) cat ("objref:", class (ref () ) [[1]], "\n", sep="")
 mutate.objref = function (ref, obj, ...) environment (ref)$obj = obj
 length.objref = function (x) length (environment (x)$obj)
-.objref.image = function () environment (sys.function (-1) )$obj
 "[.objref" = function (ref, ...) environment (ref)$obj [...]
 "[[.objref" = function (ref, ...) environment (ref)$obj [[...]]
 
@@ -23,3 +22,4 @@ length.objref = function (x) length (environment (x)$obj)
 }
 
 
+
